===
CLI
===

.. automodule:: timmy.cli
.. argparse::
   :module: timmy.cli
   :func: parser_init
   :prog: timmy

Fuel module parameters

.. argparse::
   :module: timmy.modules.fuel
   :func: prepare_args
   :prog: timmy

Local module parameters

.. argparse::
   :module: timmy.modules.local
   :func: prepare_args
   :prog: timmy

